import { Component, ViewChild, OnInit, ElementRef, AfterViewInit } from '@angular/core';
import WebViewer, { WebViewerInstance } from '@pdftron/webviewer';
import saveAs from 'file-saver';

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.css']
})
export class AppComponent implements OnInit, AfterViewInit {
  @ViewChild('viewer') viewer: ElementRef;
  wvInstance: WebViewerInstance;

  ngAfterViewInit(): void {

    WebViewer({
      path: '../lib',
      fullAPI: true,
      webviewerServerURL: 'http://localhost:8090'
    }, this.viewer.nativeElement).then(instance => {
      this.wvInstance = instance;

      // now you can access APIs through this.webviewer.getInstance()
      // instance.openElements(['notesPanel']);
      // see https://www.pdftron.com/documentation/web/guides/ui/apis for the full list of APIs

      // or listen to events from the viewer element
      this.viewer.nativeElement.addEventListener('pageChanged', (e) => {
        const [ pageNumber ] = e.detail;
        console.log(`Current page is ${pageNumber}`);
      });

      // or from the docViewer instance
      instance.Core.documentViewer.on('annotationsLoaded', () => {
        console.log('annotations loaded');
      });

      instance.Core.documentViewer.on('documentLoaded', this.wvDocumentLoadedHandler)

      instance.UI.setHeaderItems((header) => {
        console.log(header.getHeader('toolbarGroup-FillAndSign').getItems());
      });
    })
  }

  ngOnInit() {
    this.wvDocumentLoadedHandler = this.wvDocumentLoadedHandler.bind(this);
  }

  openModal(): void {
    // this.wvInstance.openElements(['signatureModal']);
  }

  modifyEvents() {
    /*
    console.log('doing');
    const oldMouseLeftDown = this.wvInstance.Tools.FreeHandCreateTool.prototype.mouseLeftDown;
    const oldMouseMove = this.wvInstance.Tools.FreeHandCreateTool.prototype.mouseMove;
    const oldMouseLeftUp = this.wvInstance.Tools.FreeHandCreateTool.prototype.mouseLeftUp;

    this.wvInstance.Tools.FreeHandCreateTool.prototype.mouseLeftDown = function(e) {
      console.log(e);
      console.log('down');
    }

    this.wvInstance.Tools.FreeHandCreateTool.prototype.mouseMove = function(e) {
      // console.log('move');
    }
    
    this.wvInstance.Tools.FreeHandCreateTool.prototype.mouseLeftUp = function(e) {
      // console.log('up');
    }
    */
  }

  wvDocumentLoadedHandler(): void {
    // you can access docViewer object for low-level APIs
    // and access classes defined in the WebViewer iframe
    /*
    const { Annotations, annotManager, docViewer } = this.wvInstance;
    const rectangle = new Annotations.RectangleAnnotation();
    rectangle.PageNumber = 1;
    rectangle.X = 100;
    rectangle.Y = 100;
    rectangle.Width = 250;
    rectangle.Height = 250;
    rectangle.StrokeThickness = 5;
    rectangle.Author = annotManager.getCurrentUser();
    annotManager.addAnnotation(rectangle);
    annotManager.drawAnnotations(rectangle.PageNumber);
    this.modifyEvents();
    */
    // see https://www.pdftron.com/api/web/WebViewer.html for the full list of low-level APIs
  }

  async save() {
    const annotManager = this.wvInstance.Core.documentViewer.getAnnotationManager();
    const doc = this.wvInstance.Core.documentViewer.getDocument();
    const xfdfString = await annotManager.exportAnnotations();
    const data = await doc.getFileData({
      xfdfString
    });
    const arr = new Uint8Array(data);
    const blob = new Blob([arr]);
    saveAs(blob, "foobar.pdf");
  }

  fileChange(event): void {
    this.wvInstance.UI.loadDocument(event.target.files[0]);
  }
}
